==> dancingparticles0.2.tgz: dancingparticles0.2/etoile.h <==

#include <cmath>
#include <GL/gl.h>
#include <cstring>

#define myfloat  GLfloat

struct Point
{
  int h,v;
};
struct Rect{
  int top,bottom,left,right;
};

typedef int Boolean;
 
class efloatPoint
{
public :
	myfloat v[3];
	efloatPoint operator +=(const efloatPoint &b){
	  for(int i=0;i<3;i++)
	    v[i]+=b.v[i];
	  return *this;
	};
	
	efloatPoint(const Point &P){
	  v[0]=P.h;
	  v[1]=P.v;
	  v[2]=20;
	};
	efloatPoint(const efloatPoint &P){
	  memcpy(v,P.v,3*sizeof(myfloat));
	};

	efloatPoint(){
	  v[0]=0;
	  v[1]=0;
	  v[2]=20;	  
	};
	efloatPoint (float a, float b, float c){
	  v[0]=a;
	  v[1]=b;
	  v[2]=c;	  
	};
	myfloat &operator [] (int i) { return v[i]; }
	const myfloat &operator [] (int i) const{ return v[i]; }

	inline myfloat length(){return (myfloat)sqrt( v[0]*v[0] + v[1]*v[1] + v[2]*v[2]);}
	


};
inline	efloatPoint operator+ (const efloatPoint &a, const efloatPoint &b){
		efloatPoint c(a);
		for(int i=0;i<3;i++)
		  c[i]+=b[i];
		return c;
		};
inline	efloatPoint operator- (const efloatPoint &a, const efloatPoint &b){
  efloatPoint c(a);
  for(int i=0;i<3;i++)
    c[i]-=b[i];
  return c;
}
inline	efloatPoint operator* (const efloatPoint &a, const myfloat &b){
  efloatPoint c(a);
  for(int i=0;i<3;i++)
    c[i]*=b;
  return c;
}
inline	efloatPoint operator/ (const efloatPoint &a, const float &b){
  efloatPoint c(a);
  for(int i=0;i<3;i++)
    c[i]/=b;
  return c;
};

inline	myfloat operator % (const efloatPoint &a, const efloatPoint &b){
  return a[0]*b[0] + a[1]*b[1] +a[2]*b[2];
}

inline	efloatPoint operator * (const efloatPoint &a, const efloatPoint &b){
  
  return efloatPoint(a[0]*b[1]-a[1]*b[0],
		     a[1]*b[2]-a[2]*b[1],
		     a[2]*b[0]-a[0]*b[2]);

}

#include "matrix.h"

/* Globals */

struct parameters
{
  int mode;
  myfloat k;      // cst du ressort
  myfloat d0min;  // longueur min
  myfloat d1;     // longueur du cercle du centre
  myfloat ag;     // antigravit
  int antigorder;
  myfloat maxantig;
  int noagexplosion;
  myfloat dancingpart; // in %
  myfloat velocity;
  int     numfrq;
  myfloat visc;
  myfloat rotspeed1;
  myfloat rotspeed2;
  int strombo;    // 1 = no strombo



  int chance;   
};

extern parameters p;

enum
{
  ptsNumMax=200,
	ptsNumMin=ptsNumMax,
	//	d0=100
};

extern efloatPoint pts[ptsNumMax+10];
extern efloatPoint speed[ptsNumMax+10];
extern efloatPoint Center;
extern short ptsNum;
extern int beat;
extern int beatcnt;
extern int thick, quiet;
extern parameters ps[];
extern int nump;

/* Prototypes */

void etoileinit();
void etoileLoop(void);

void DrawNum(float f,int i);
void	DrawPt(int i);	
void DrawCenter();
void BeginDrawing();
void EndDrawing();
int emain(void);
Boolean eTestEnd();
efloatPoint eSetCenter(long time);

==> dancingparticles0.4.tgz: dancingparticles0.4/etoile.h <==

#include <cmath>
#include <GL/glut.h>
#include <cstring>

#define myfloat  GLfloat

struct Point
{
  int h,v;
};
struct Rect{
  int top,bottom,left,right;
};

typedef int Boolean;
 
class efloatPoint
{
public :
	myfloat v[3];
	efloatPoint operator +=(const efloatPoint &b){
	  for(int i=0;i<3;i++)
	    v[i]+=b.v[i];
	  return *this;
	};
	
	efloatPoint(const Point &P){
	  v[0]=P.h;
	  v[1]=P.v;
	  v[2]=20;
	};
	efloatPoint(const efloatPoint &P){
	  memcpy(v,P.v,3*sizeof(myfloat));
	};

	efloatPoint(){
	  v[0]=0;
	  v[1]=0;
	  v[2]=20;	  
	};
	efloatPoint (float a, float b, float c){
	  v[0]=a;
	  v[1]=b;
	  v[2]=c;	  
	};
	myfloat &operator [] (int i) { return v[i]; }
	const myfloat &operator [] (int i) const{ return v[i]; }

	inline myfloat length(){return (myfloat)sqrt( v[0]*v[0] + v[1]*v[1] + v[2]*v[2]);}
	void display()
	  {
	    cout << v[0] <<" "<< v[1] <<" " << v[2] <<endl;  
	  }


};
inline	efloatPoint operator+ (const efloatPoint &a, const efloatPoint &b){
		efloatPoint c(a);
		for(int i=0;i<3;i++)
		  c[i]+=b[i];
		return c;
		};
inline	efloatPoint operator- (const efloatPoint &a, const efloatPoint &b){
  efloatPoint c(a);
  for(int i=0;i<3;i++)
    c[i]-=b[i];
  return c;
}
inline	efloatPoint operator* (const efloatPoint &a, const myfloat &b){
  efloatPoint c(a);
  for(int i=0;i<3;i++)
    c[i]*=b;
  return c;
}
inline	efloatPoint operator/ (const efloatPoint &a, const float &b){
  efloatPoint c(a);
  for(int i=0;i<3;i++)
    c[i]/=b;
  return c;
};

inline	myfloat operator % (const efloatPoint &a, const efloatPoint &b){
  return a[0]*b[0] + a[1]*b[1] +a[2]*b[2];
}

inline	efloatPoint operator * (const efloatPoint &a, const efloatPoint &b){
  
  return efloatPoint(a[0]*b[1]-a[1]*b[0],
		     a[1]*b[2]-a[2]*b[1],
		     a[2]*b[0]-a[0]*b[2]);

}

#include "matrix.h"

/* Globals */

struct parameters
{
  char *name;
  char key;
  int mode;
  myfloat k;      // cst du ressort
  myfloat d0min;  // longueur min
  myfloat d1;     // longueur du cercle du centre
  myfloat ag;     // antigravit
  int antigorder;
  int agnumparts;
  myfloat maxantig;
  int noagexplosion;
  myfloat dancingpart; // in %
  int dancingpartk;
  myfloat velocity;
  int     numfrq;
  myfloat visc;
  myfloat rotspeed1;
  myfloat rotspeed2;
  int strombo;    // 1 = no strombo

  int numpart;
  myfloat size;
  myfloat sizeloudness;

  int chance;
  int duration_f; 
  int duration_b;
};

extern parameters p;


extern efloatPoint *pts;
extern efloatPoint *speed;
extern efloatPoint *Centers;
extern int         *newline;
extern efloatPoint *Centers2; // used to build the Centers  TODO need to be a better data struct for Centers
extern int         *newline2;
extern int numCenters;
extern int numCenters2;

extern efloatPoint Center;
extern int ptsNum, ptsNumMax;

extern int beat;
extern int beatcnt;
extern int thick, quiet;
extern GLfloat heights[64];

extern parameters *ps;
extern int nump;
extern int frames;

/* Prototypes */

void etoileLoop(void);

void	DrawPt(int i);	
void DrawCenter();
void BeginDrawing();
void EndDrawing();
Boolean eTestEnd();
efloatPoint eSetCenter(long time);
void Tourne(short i);
void Elastantig(short i,efloatPoint &c);

// parameters
void etoileinit();
void  init_parameters();
void changep();
void allocParts();

void loadepic(char *file);
